import React from "react";
import styles from "./DropDownInput.module.css";
import { useState } from "react";
import useClickOutside from "../../hooks/use-click-outside";
import { ArrowIcon } from "../Icons/Icons";
import useParentProps from "../../hooks/use-parent-props";
import { CSSTransition } from "react-transition-group";
import { Direction } from "../../interfaces/Utilities";
function DropDownInput({ options, label, onChange }) {
    const [menuTitleIndex, setMenuTitleIndex] = useState();
    const [isOpen, setIsOpen] = useState(false);
    const { ref: parentRef, parentProps } = useParentProps();
    const { ref: menuRef } = useClickOutside(() => setIsOpen(false), parentRef);
    const handleMenuToggle = () => {
        setIsOpen(!isOpen);
    };
    const handleSelect = (new_title_index) => {
        setMenuTitleIndex(new_title_index);
        onChange();
        setIsOpen(false);
    };
    const inputWidth = Math.max(Math.max(...options.map((el) => el.length)), "Select".length) *
        1.7;
    return (React.createElement(React.Fragment, null,
        label && React.createElement("label", { className: styles.label }, label),
        React.createElement("button", { style: {
                width: `${inputWidth}ch`,
            }, ref: parentRef, className: styles.title, onClick: handleMenuToggle },
            React.createElement("span", null, menuTitleIndex !== undefined ? options[menuTitleIndex] : "Select"),
            React.createElement(ArrowIcon, { className: styles.arrow, direction: Direction.down })),
        React.createElement(CSSTransition, { nodeRef: menuRef, in: isOpen, timeout: 300, classNames: {
                enter: styles.menuEnter,
                enterActive: styles.menuEnterActive,
                exit: styles.menuExit,
                exitActive: styles.menuExitActive,
            }, unmountOnExit: true },
            React.createElement("ul", { ref: menuRef, className: styles.menu, style: {
                    width: `${inputWidth + 3.5}ch`,
                    top: `${parentProps.top + 30}px`,
                    left: `${parentProps.left}px`,
                } }, options.map((value, index) => {
                return (React.createElement("li", { className: `${index === menuTitleIndex ? styles.selected : ""}`, key: index, onClick: () => handleSelect(index) }, value));
            })))));
}
export default DropDownInput;
