import React from "react";
import styles from "./DropDownMenu.module.css";
import { useState } from "react";
import useClickOutside from "../../hooks/use-click-outside";
import { ArrowIcon } from "../Icons/Icons";
import useParentProps from "../../hooks/use-parent-props";
import { CSSTransition } from "react-transition-group";
import Link from "../Link/Link";
import { Direction } from "../../interfaces/Utilities";
const getArrowDirection = function (menuPosition, isOpen) {
    switch (menuPosition) {
        case Direction.down:
            if (isOpen)
                return Direction.up;
            return Direction.down;
        case Direction.up:
            if (isOpen)
                return Direction.down;
            return Direction.up;
        case Direction.left:
            if (isOpen)
                return Direction.right;
            return Direction.left;
        case Direction.right:
            if (isOpen)
                return Direction.left;
            return Direction.right;
    }
};
function DropDownMenu({ menuItems, label, menuPosition }) {
    var _a;
    menuPosition = menuPosition ? menuPosition : Direction.down;
    const [isOpen, setIsOpen] = useState(false);
    const [activeMenu, setActiveMenu] = useState(menuItems);
    const { ref: parentRef, parentProps } = useParentProps();
    const { ref: menuRef } = useClickOutside(() => setIsOpen(false), parentRef);
    const handleMenuToggle = () => {
        setIsOpen(!isOpen);
    };
    const arrowPosition = () => getArrowDirection(menuPosition, isOpen);
    const getMenuPosition = function () {
        var _a;
        switch (menuPosition) {
            case Direction.down:
                return {
                    top: `${parentProps.top + 30}px`,
                    left: `${parentProps.left}px`,
                };
            case Direction.right:
                return {
                    top: `${parentProps.top - 16}px`,
                    left: `${parentProps.right + 5}px`,
                };
            case Direction.left:
                return {
                    top: `${parentProps.top - 16}px`,
                    left: `${parentProps.left - parentProps.width - 5}px`,
                };
            case Direction.up:
                const rowHeight = 60;
                return {
                    top: `${parentProps.top - (((_a = activeMenu.submenu) === null || _a === void 0 ? void 0 : _a.length) || 0) * rowHeight}px`,
                    left: `${parentProps.left}px`,
                };
        }
        return {};
    };
    const animationClasses = {
        enter: styles[`menuEnter${menuPosition}`],
        enterActive: styles[`menuEnterActive${menuPosition}`],
        exit: styles[`menuExit${menuPosition}`],
        exitActive: styles[`menuExitActive${menuPosition}`],
    };
    return (React.createElement(React.Fragment, null,
        menuItems.submenu ? (React.createElement(React.Fragment, null,
            label && React.createElement("label", null, label),
            React.createElement("button", { style: { width: `${menuItems.title.length * 1.6}ch` }, "aria-expanded": isOpen, ref: parentRef, className: styles.title, onClick: handleMenuToggle },
                React.createElement("span", null, activeMenu.title),
                React.createElement(ArrowIcon, { className: styles.arrow, direction: arrowPosition() })))) : (React.createElement(Link, { href: activeMenu.url, className: styles.titleLink, style: { maxWidth: `${menuItems.title.length * 1.6}ch` } }, activeMenu.title)),
        React.createElement(CSSTransition, { nodeRef: menuRef, in: isOpen, timeout: 300, classNames: animationClasses, onExited: () => {
                setActiveMenu(menuItems);
            }, unmountOnExit: true },
            React.createElement("ul", { ref: menuRef, className: styles.menu, style: Object.assign({ maxWidth: "fit-content", minWidth: `${parentProps.width}px` }, getMenuPosition()) }, (_a = activeMenu.submenu) === null || _a === void 0 ? void 0 : _a.map((item, index) => {
                return (React.createElement(MenuItems, { setMenu: (menu) => {
                        setIsOpen(false);
                        setActiveMenu(menu);
                        setIsOpen(true);
                    }, arrowPosition: getArrowDirection(menuPosition, false), key: index, item: item }));
            })))));
}
export function MenuItems({ item, setMenu, arrowPosition, }) {
    return (React.createElement("li", null, item.hasOwnProperty("submenu") ? (React.createElement("button", { type: "button", onClick: () => {
            if (setMenu)
                setMenu(item);
        } },
        item.title,
        React.createElement(ArrowIcon, { className: styles.submenuArrow, direction: arrowPosition }))) : (React.createElement(Link, { className: styles.linkTest, href: item.url }, item.title))));
}
export default DropDownMenu;
